pyxmpp.sasl.gssapi.GSSAPIClientAuthenticator

Package pyxmpp :: Package sasl :: Module gssapi :: Class GSSAPIClientAuthenticator |
[hide private]

# Class GSSAPIClientAuthenticator

source code

    core.ClientAuthenticator --+
                               |
                              GSSAPIClientAuthenticator

Provides client-side GSSAPI SASL (Kerberos 5) authentication.

Instance Methods | [hide private]
__init__(self, password_manager) Initialize a ClientAuthenticator object. | source code
Response or Failure |
start(self, username, authzid) Start the authentication process. | source code
Response or Failure |
challenge(self, challenge) Process the server's challenge. | source code
Success or Failure |
finish(self, data) Handle authentication succes information from the server. | source code

Method Details | [hide private]

### __init__(self, password_manager) (Constructor) | source code
Initialize a ClientAuthenticator object. Parameters: `password_manager` - a password manager providing authentication credentials. Overrides: core.ClientAuthenticator.__init__ (inherited documentation)

### start(self, username, authzid) | source code
Start the authentication process. Parameters: `username` - the username (authentication id). `authzid` - the authorization id requester. Returns: Response or Failure the initial response to send to the server or a failuer indicator. Overrides: core.ClientAuthenticator.start (inherited documentation)

### challenge(self, challenge) | source code
Process the server's challenge. Parameters: `challenge` - the challenge. Returns: Response or Failure the response or a failure indicator. Overrides: core.ClientAuthenticator.challenge (inherited documentation)

### finish(self, data) | source code
Handle authentication succes information from the server. Parameters: `data` - the optional additional data returned with the success. Returns: Success or Failure success or failure indicator. Overrides: core.ClientAuthenticator.finish (inherited documentation)